@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-static
 version: 1.5.0.3
-id: yesod-static-1.5.0.3-2bc87d4464cddb59d7480c11330f08e3
-key: yesod_4p8OpkhYgOt35CBQ0NXbge
+id: yesod-static-1.5.0.3-ead9a694a8cbdc31a2efb629bc5fd744
+key: yesod_0ULV3E7AC95HxAMpnSiUtc
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -23,7 +23,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
-hs-libraries: HSyesod-static-1.5.0.3-4p8OpkhYgOt35CBQ0NXbge
+hs-libraries: HSyesod-static-1.5.0.3-0ULV3E7AC95HxAMpnSiUtc
 depends:
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
@@ -33,10 +33,10 @@ depends:
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
-    cryptohash-conduit-0.1.1-9cd42855330eec21f69d5ac4f36d7158
+    cryptohash-conduit-0.1.1-dcc54b18eae719b780790ad6d75d2817
     css-text-0.1.2.1-5f08c8634ff151127fcfba990f98863f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
@@ -54,9 +54,9 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    wai-app-static-3.1.4.1-2771ede2f82f698f69c7f5569f69b185
-    yesod-core-1.4.19-b6ec8d224ea1c49c36126eee73b10ab6
+    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    wai-app-static-3.1.5-c99c41fb98f5790941b5a0bc818346a5
+    yesod-core-1.4.20-a64b314810952b5a1be9638e42c84862
 haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
 haddock-html: /usr/share/doc/haskell-yesod-static/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
